#
# spec file for package raspberrypi-firmware
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           raspberrypi-firmware
Version:        2019.11.19
Release:        lp151.4.3.1
Summary:        Binary bootloader and firmware files for Raspberry Pi
License:        SUSE-Firmware
Group:          System/Boot
URL:            https://github.com/raspberrypi/firmware/
Source0:        raspberrypi-firmware-%{version}.tar.bz2
Source1:        get-from-git.sh
Source99:       %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(post): util-linux
Recommends:     raspberrypi-firmware-dt
Recommends:     raspberrypi-firmware-config

%description
Binary bootloader and firmware files for Raspberry Pi

%package extra
Summary:        Extra bootloaders for Raspberry Pi
Group:          System/Boot
Requires:       raspberrypi-firmware = %{version}-%{release}
Requires(post): util-linux

%description extra
This package provides the console, experimental and debug
firmware files for Raspberry Pi

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}/boot/vc
cp -a boot/start.elf boot/start_*.elf  %{buildroot}/boot/vc
cp -a boot/fixup.dat boot/fixup_*.dat %{buildroot}/boot/vc
cp -a boot/*.bin boot/LICENCE.broadcom %{buildroot}/boot/vc

%post
if mountpoint -q /boot/efi && [[ ! -L /boot/efi ]]; then
  for f in start.elf fixup.dat bootcode.bin; do
    cp /boot/vc/$f /boot/efi/
  done
fi

%post extra
if mountpoint -q /boot/efi && [[ ! -L /boot/efi ]]; then
  for suffix in _cd _db _x; do
    cp /boot/vc/start${suffix}.elf /boot/efi/
    cp /boot/vc/fixup${suffix}.dat /boot/efi/
  done
fi

%files
%defattr(-,root,root)
%dir /boot/vc
/boot/vc/start.elf
/boot/vc/fixup.dat
/boot/vc/bootcode.bin
%doc /boot/vc/LICENCE.broadcom

%files extra
%defattr(-,root,root)
/boot/vc/start_cd.elf
/boot/vc/start_db.elf
/boot/vc/start_x.elf
/boot/vc/fixup_cd.dat
/boot/vc/fixup_db.dat
/boot/vc/fixup_x.dat

%changelog
* Wed Jan  8 2020 Matthias Brugger <mbrugger@suse.com>
- Update to 6e4a7232c (2019-11-19):
  - Add support for CM3+ (bsc#1157822)
* Thu Apr  5 2018 agraf@suse.com
- Allow user defined config options (bsc#1088356)
- Move HDMI workaround to rpi3 section (fixes RPi2 HDMI output)
* Wed Mar 14 2018 agraf@suse.com
- Update to 3347884 (2018-03-13)
  - Add support for new RPi3 B+ (bsc#1085262)
* Mon Feb 19 2018 agraf@suse.com
- Add overlays to match previous U-Boot provided DT
- Add Recommends: on dt and config packages
* Fri Feb 16 2018 agraf@suse.com
- Update to 445b6a8 (2018-02-09)
* Wed Jan 31 2018 jengelh@inai.de
- Avoid bashisms in %%post
* Mon Jan 22 2018 agraf@suse.com
- Merge config.txt files into a single config.txt with subsections
- Set GPU memory usage to 32MB, this is enough for vc4 (boo#1074566)
- Update to 050175d (2018-01-17)
* Sat Nov 25 2017 afaerber@suse.de
- Add rpi0w sub-package and config (boo#1069828). Derived from rpi3.
- Update to abfb4be3e1 (2017-11-17)
* Thu Oct 12 2017 guillaume@opensuse.org
- Update to a88e126a (2017-10-11)
* Wed Aug 23 2017 guillaume@opensuse.org
- Update to 8fe001e (2017-08-22)
* Wed Apr 19 2017 afaerber@suse.de
- Update to b038854 (2017-04-04)
* Mon Feb 20 2017 malcolmlewis@opensuse.org
- Update to 2b495ac (2017-02-20)
* Thu Jan 12 2017 guillaume@opensuse.org
- Update to e44f66a (2017-01-10)
* Fri Nov 18 2016 guillaume@opensuse.org
- Update to 64996b0 (2016-11-16)
* Tue Oct 25 2016 guillaume@opensuse.org
- Update to 4a0e54e (2016-10-20)
* Wed Oct 12 2016 guillaume@opensuse.org
- Update to a021d6e (2016-10-11)
* Tue Sep 27 2016 guillaume@opensuse.org
- Increase from 64 MB to 96 MB of RAM for GPU for RPi with 256 or
  512 MB of RAM to be able to decode a 1080p h264 video in kodi
* Tue Sep 27 2016 guillaume@opensuse.org
- Update to ad8608c (2016-09-21)
* Thu Sep 15 2016 fvogt@suse.com
- Use "avoid_warnings=1" in config-rpi{,2,3}.txt (bsc#998973)
* Mon Sep 12 2016 afaerber@suse.de
- Clean up config-{rpi2,rpi3}.txt, dropping rpi1 defaults
  * On the rpi1 Model B rev. 2 performance results are similar
  with and without defaults, so in doubt leave our settings in
  config-rpi.txt until proven the defaults work better somewhere.
* Tue Sep  6 2016 fvogt@suse.com
- Use default frequencies in config-rpi{2,3}.txt (bsc#989511)
  * Defaults work well on rpi2
  * Allow much higher frequencies on rpi3
* Fri Sep  2 2016 afaerber@suse.de
- get-from-git.sh: Update for -config-rpi* sub-packages
- Update to 334f548 (2016-09-02)
- Add post-install scripts to copy files to /boot/efi where needed.
  /boot/vc may be the mountpoint for boot.scr based installations
  or a symlink to /boot/efi. (bsc#996064)
* Wed Aug 24 2016 mpluskal@suse.com
- Update to d0bc6ce (2016.08.23)
* Thu Jul 21 2016 mpluskal@suse.com
- Update to 051aed7 (2016.07.15)
- Simplify spec file a bit
* Thu Jun 16 2016 afaerber@suse.de
- Fix last changelog entry
- Run format_spec_file in pre_checkin.sh to fix spec file header
- Restore silently dropped defattr that breaks older builds
* Mon Jun  6 2016 dmueller@suse.com
- remove branding-openSUSE subpackage and split config
  into the 3 variants for (rpi, rpi2, rpi3)
* Tue May 31 2016 guillaume@opensuse.org
- Update to ac0c0bf (2016-05-20)
* Tue May 10 2016 dmueller@suse.com
- mark package as noarch (adds rpmlintrc)
- split extra bootloaders into separate -extra subpackage
* Wed May  4 2016 afaerber@suse.de
- Enable aarch64 builds for Raspberry Pi 3
* Fri Apr 29 2016 guillaume@opensuse.org
- Update to 20958cd (2016-04-27)
* Wed Apr  6 2016 guillaume@opensuse.org
- Update to c065500 (2016-04-05)
* Mon Mar  7 2016 afaerber@suse.de
- Revert to last actual change b48c36f (2016-03-04)
- Fix version bug found by Guillaume by using git-log (as intended)
* Mon Mar  7 2016 guillaume@opensuse.org
- Update to 845eb06 (2016-03-05)
* Mon Mar  7 2016 guillaume@opensuse.org
- Fix get-from-git.sh to get version even when packaged files are
  not in the last commit
* Tue Mar  1 2016 guillaume@opensuse.org
- Update Config.txt (add GPU mem option for 1024 MB version)
* Tue Mar  1 2016 guillaume@opensuse.org
- Update to 9cd1c6c (2016-02-29)
* Thu Feb 25 2016 guillaume@opensuse.org
- Update to 565197e (2016-02-19)
* Thu Feb  4 2016 guillaume@opensuse.org
- Update to cb2ffaa (2016-02-01)
* Thu Jan 14 2016 guillaume@opensuse.org
- Update to 7147575 (2016-01-13)
* Tue Dec  8 2015 afaerber@suse.de
- Update to 224c756 (2015-12-08)
* Tue Dec  8 2015 afaerber@suse.de
- Move files from /boot to /boot/vc to allow directly updating the
  FAT partition through a /boot/vc mount
- Require the main package for the branding package
* Sun Nov 29 2015 afaerber@suse.de
- Update to ed611df (2015-11-25)
  * Clarifies licensing of start_*.elf files
- Improve get-from-git.sh
  * Automate file removal and addition
  * Use date of last relevant change
- Add branding-openSUSE subpackage, based on a to-do item in
  openSUSE:Factory:ARM JeOS package's uboot-image-install.in script
  * Update comment about zImage to reflect current U-Boot situation
* Wed Oct 28 2015 afaerber@suse.de
- Add get-from-git.sh script as source file (sr#341314)
* Mon Oct 26 2015 afaerber@suse.de
- Update to 4047fe2 (2015-10-23)
- Throw out all non-free gfx sub-packages and files
* Mon Oct 12 2015 guillaume@opensuse.org
- Update to ba7a8fb (2015-10-11)
* Mon Aug 17 2015 guillaume@opensuse.org
- Update to e1e2823 (2015-08-15)
* Fri Aug 14 2015 guillaume@opensuse.org
- Update to c25cc51 (2015-08-13)
* Mon Jul 20 2015 guillaume@opensuse.org
- Update to cf20cb2 (2015-07-17)
* Tue Jun 23 2015 guillaume@opensuse.org
- Update to e8f6e12 (2015-06-22)
* Thu Jun  4 2015 guillaume@opensuse.org
- Update to 16044ee (2015-06-02)
* Mon Feb 16 2015 guillaume@opensuse.org
- Add %%{_bindir}/raspividyuv
* Mon Feb 16 2015 guillaume@opensuse.org
- Update to 8aca576 (2015-02-14)
* Tue Feb 10 2015 bill@merriam.net
- Update spec file to change ExclusiveArch to %%arm to support the ARMv7 RPi
* Wed Nov  5 2014 guillaume@opensuse.org
- Update to 0080d30 (2014-11-04)
* Thu Oct 16 2014 guillaume@opensuse.org
- Update to e4afeda (2014-10-12)
* Wed May 14 2014 bwiedemann@suse.com
- Update to c0319ac (2014-05-13)
* Wed Oct 30 2013 guillaume@opensuse.org
- Add "Provides: libEGL.so.1 libGLESv1_CM.so.1 libGLESv2.so.2" to
  fix libs deps
* Tue Oct 29 2013 guillaume@opensuse.org
- Fix Mesa conflicts for EGL, GLESv1 and GLESv2 libs
* Tue Oct 29 2013 guillaume@opensuse.org
- Update to 4c14569 (2013-10-18)
* Mon Sep  9 2013 guillaume.gardet@opensuse.org
- Move bins and libs to standard path (/usr/*) so remove /opt/vc/lib
    from lib search path (keep symlinks in /opt/vc for compatibility
    purpose)
* Sun Sep  8 2013 seife+obs@b1-systems.com
- Update to f6bb324 (2013-09-07)
- add script to fetch tarball from git
- add /opt/vc/lib to library search path so that demo apps in
  raspberrypi-gfx actually work
* Thu Jul  4 2013 guillaume@opensuse.org
- Update to ca5f9c4 (2013-07-02) and now use hardfp
* Wed Jul  3 2013 guillaume@opensuse.org
- Enable build for armv6l
* Mon Apr  8 2013 lars@linux-schulserver.de
- Update to baa3ecffe6 (2013-04-08):
  + ALSA fix to improve mame audio.
  + Add camera demo apps.
  + Removed unnecessary executable bits in documentation
  + improved README
* Sun Dec 30 2012 bwiedemann@suse.com
- Update to 76d0ac3 (2012-12-28) to support 512MB RAM
* Thu Oct 25 2012 guillaume@opensuse.org
- Update to 14a55da (2012.10.21) and add support to GFX
* Fri Oct 19 2012 bwiedemann@suse.com
- rename output to raspberrypi-firmware to be consistent
* Sun Aug 12 2012 bwiedemann@suse.com
- initial package from
  https://github.com/raspberrypi/firmware/ cb9513f
